@@ -29,6 +29,8 @@
 
 #include <algorithm>
 
+using namespace Qt::StringLiterals;
+
 Q_DECLARE_LOGGING_CATEGORY(KABOUTDATA)
 // logging category for this framework, default: log stuff >= warning
 Q_LOGGING_CATEGORY(KABOUTDATA, "kf.coreaddons.kaboutdata", QtWarningMsg)
@@ -144,8 +146,10 @@ QString KAboutLicensePrivate::spdxID() const
         return QStringLiteral("GPL-2.0");
     case KAboutLicense::LGPL_V2:
         return QStringLiteral("LGPL-2.0");
-    case KAboutLicense::BSDL:
+    case KAboutLicense::BSD_2_Clause:
         return QStringLiteral("BSD-2-Clause");
+    case KAboutLicense::BSD_3_Clause:
+        return QStringLiteral("BSD-3-Clause");
     case KAboutLicense::Artistic:
         return QStringLiteral("Artistic-1.0");
     case KAboutLicense::GPL_V3:
@@ -156,6 +160,16 @@ QString KAboutLicensePrivate::spdxID() const
         return QStringLiteral("LGPL-2.1");
     case KAboutLicense::MIT:
         return QStringLiteral("MIT");
+    case KAboutLicense::ODbL_V1:
+        return QStringLiteral("ODbL-1.0");
+    case KAboutLicense::Apache_V2:
+        return QStringLiteral("Apache-2.0");
+    case KAboutLicense::FTL:
+        return QStringLiteral("FTL");
+    case KAboutLicense::BSL_V1:
+        return QStringLiteral("BSL-1.0");
+    case KAboutLicense::CC0_V1:
+        return QStringLiteral("CC0-1.0");
     case KAboutLicense::Custom:
     case KAboutLicense::File:
     case KAboutLicense::Unknown:
@@ -211,7 +225,9 @@ QString KAboutLicense::text() const
 
     const QString lineFeed = QStringLiteral("\n\n");
 
-    if (d->_aboutData && !d->_aboutData->copyrightStatement().isEmpty()) {
+    if (d->_aboutData && !d->_aboutData->copyrightStatement().isEmpty()
+        && (d->_licenseKey == KAboutLicense::BSD_2_Clause || d->_licenseKey == KAboutLicense::BSD_3_Clause || d->_licenseKey == KAboutLicense::MIT
+            || d->_licenseKey == KAboutLicense::Artistic)) {
         result = d->_aboutData->copyrightStatement() + lineFeed;
     }
 
@@ -229,7 +245,7 @@ QString KAboutLicense::text() const
         knownLicense = true;
         pathToFile = QStringLiteral("LGPL_V2");
         break;
-    case KAboutLicense::BSDL:
+    case KAboutLicense::BSD_2_Clause:
         knownLicense = true;
         pathToFile = QStringLiteral("BSD");
         break;
@@ -253,6 +269,18 @@ QString KAboutLicense::text() const
         knownLicense = true;
         pathToFile = QStringLiteral("MIT");
         break;
+    case KAboutLicense::ODbL_V1:
+    case KAboutLicense::Apache_V2:
+    case KAboutLicense::FTL:
+    case KAboutLicense::BSL_V1:
+    case KAboutLicense::BSD_3_Clause:
+    case KAboutLicense::CC0_V1:
+        knownLicense = true;
+        result += QCoreApplication::translate("KAboutLicense", "This program is distributed under the terms of the %1.").arg(name(KAboutLicense::ShortName))
+            + u"\n\n"_s
+            + QCoreApplication::translate("KAboutLicense", "You can find the full term <a href=\"https://spdx.org/licenses/%1.html\">the SPDX website</a>")
+                  .arg(d->spdxID());
+        break;
     case KAboutLicense::Custom:
         if (!d->_licenseText.isEmpty()) {
             result = d->_licenseText;
@@ -320,7 +348,7 @@ QString KAboutLicense::name(KAboutLicense::NameFormat formatName) const
         licenseShort = QCoreApplication::translate("KAboutLicense", "LGPL v2", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "GNU Lesser General Public License Version 2", "@item license");
         break;
-    case KAboutLicense::BSDL:
+    case KAboutLicense::BSD_2_Clause:
         licenseShort = QCoreApplication::translate("KAboutLicense", "BSD License", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "BSD License", "@item license");
         break;
@@ -344,6 +372,30 @@ QString KAboutLicense::name(KAboutLicense::NameFormat formatName) const
         licenseShort = QCoreApplication::translate("KAboutLicense", "MIT License", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "MIT License", "@item license");
         break;
+    case KAboutLicense::CC0_V1:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "CC0", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "Creative Commons Zero", "@item license");
+        break;
+    case KAboutLicense::ODbL_V1:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "ODbL v1.0", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "Open Data Commons Open Database License v1.0", "@item license");
+        break;
+    case KAboutLicense::Apache_V2:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "Apache 2.0", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "Apache License 2.0", "@item license");
+        break;
+    case KAboutLicense::FTL:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "FTL", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "Freetype Project License", "@item license");
+        break;
+    case KAboutLicense::BSL_V1:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "Boost License", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "Boost Software License 1.0", "@item license");
+        break;
+    case KAboutLicense::BSD_3_Clause:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "BSD-3-Clause", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "BSD 3-Clause \"New\" or \"Revised\" License", "@item license");
+        break;
     case KAboutLicense::Custom:
     case KAboutLicense::File:
         licenseShort = licenseFull = QCoreApplication::translate("KAboutLicense", "Custom", "@item license");
@@ -378,7 +430,8 @@ KAboutLicense KAboutLicense::byKeyword(const QString &rawKeyword)
         {"gpl20+", KAboutLicense::GPL_V2},     {"lgpl", KAboutLicense::LGPL},
         {"lgplv2", KAboutLicense::LGPL_V2},    {"lgplv2+", KAboutLicense::LGPL_V2},
         {"lgpl20", KAboutLicense::LGPL_V2},    {"lgpl20+", KAboutLicense::LGPL_V2},
-        {"bsd", KAboutLicense::BSDL},          {"bsd2clause", KAboutLicense::BSDL},
+        {"bsd", KAboutLicense::BSD_2_Clause},  {"bsd2clause", KAboutLicense::BSD_2_Clause},
+        {"apache", KAboutLicense::Apache_V2},  {"bsd3clause", KAboutLicense::BSD_3_Clause},
         {"artistic", KAboutLicense::Artistic}, {"artistic10", KAboutLicense::Artistic},
         {"gplv3", KAboutLicense::GPL_V3},      {"gplv3+", KAboutLicense::GPL_V3},
         {"gpl30", KAboutLicense::GPL_V3},      {"gpl30+", KAboutLicense::GPL_V3},
@@ -616,6 +669,18 @@ KAboutData &KAboutData::addAuthor(const QString &name, const QString &task, cons
     return *this;
 }
 
+KAboutData &KAboutData::addAuthor(const KAboutPerson &author)
+{
+    d->_authorList.append(author);
+    return *this;
+}
+
+KAboutData &KAboutData::addCredit(const KAboutPerson &person)
+{
+    d->_creditList.append(person);
+    return *this;
+}
+
 KAboutData &KAboutData::addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QUrl &avatarUrl)
 {
     d->_creditList.append(KAboutPerson(name, task, emailAddress, webAddress, avatarUrl));
@@ -628,6 +693,12 @@ KAboutData &KAboutData::setTranslator(const QString &name, const QString &emailA
     return *this;
 }
 
+KAboutData &KAboutData::addComponent(const KAboutComponent &component)
+{
+    d->_componentList.append(component);
+    return *this;
+}
+
 KAboutData &KAboutData::addComponent(const QString &name,
                                      const QString &description,
                                      const QString &version,
